@@ -75,12 +75,29 @@ import com.openexchange.jsieve.exceptions.OXSieveHandlerInvalidCredentialsExcept
  */
 public class SieveHandler {
 
+    /**
+     * The logger.
+     */
+    private static Log log = LogFactory.getLog(SieveHandler.class);
+
+    /**
+     * The constant for CRLF (carriage-return line-feed).
+     */
     private final static String CRLF = "\r\n";
 
+    /**
+     * The SIEVE OK.
+     */
     private final static String SIEVE_OK = "OK";
 
+    /**
+     * The SIEVE NO.
+     */
     private final static String SIEVE_NO = "NO";
 
+    /**
+     * The SIEVE AUTHENTICATE.
+     */
     private final static String SIEVE_AUTH = "AUTHENTICATE ";
 
     private final static String SIEVE_AUTH_FAILD = "NO \"Authentication Error\"";
@@ -115,15 +132,17 @@ public class SieveHandler {
 
     private boolean AUTH = false;
 
-    private String sieve_user = null;
+    private final String sieve_user;
 
-    private String sieve_auth = null;
+    private final String sieve_auth;
 
-    private String sieve_auth_passwd = null;
+    private final String sieve_auth_enc;
 
-    private String sieve_host = "127.0.0.1";
+    private final String sieve_auth_passwd;
 
-    private int sieve_host_port = 2000;
+    private final String sieve_host;
+
+    private final int sieve_host_port;
 
     private Capabilities capa = null;
 
@@ -133,8 +152,6 @@ public class SieveHandler {
 
     private BufferedOutputStream bos_sieve = null;
 
-    private static Log log = LogFactory.getLog(SieveHandler.class);
-
     private long mStart;
 
     private long mEnd;
@@ -149,20 +166,22 @@ public class SieveHandler {
      * @param host
      * @param port
      */
-    public SieveHandler(final String userName, final String passwd, final String host, final int port) {
+    public SieveHandler(final String userName, final String passwd, final String host, final int port, final String authEnc) {
         sieve_user = userName;
         sieve_auth = userName;
+        sieve_auth_enc = authEnc;
         sieve_auth_passwd = passwd;
-        sieve_host = host;
-        sieve_host_port = port;
+        sieve_host = host; // "127.0.0.1"
+        sieve_host_port = port; // 2000
     }
 
-    public SieveHandler(final String userName, final String authUserName, final String authUserPasswd, final String host, final int port) {
+    public SieveHandler(final String userName, final String authUserName, final String authUserPasswd, final String host, final int port, final String authEnc) {
         sieve_user = userName;
         sieve_auth = authUserName;
+        sieve_auth_enc = authEnc;
         sieve_auth_passwd = authUserPasswd;
-        sieve_host = host;
-        sieve_host_port = port;
+        sieve_host = host; // "127.0.0.1"
+        sieve_host_port = port; // 2000
 
     }
 
@@ -256,10 +275,11 @@ public class SieveHandler {
             bis_sieve = new BufferedReader(new InputStreamReader(s_sieve.getInputStream(), "UTF-8"));
             bos_sieve = new BufferedOutputStream(s_sieve.getOutputStream());
             /*
-             * Fire CAPABILITY command but only for cyrus that is not sieve draft conform to sent CAPABILITY response again directly as
-             * response for the STARTTLS command.
+             * Fire CAPABILITY command but only for cyrus and NEMESIS that is not sieve draft conform to sent CAPABILITY response again
+             * directly as response for the STARTTLS command.
              */
-            if (capa.getImplementation().startsWith("Cyrus") || capa.getImplementation().startsWith("NEMESIS")) {
+            String implementation = capa.getImplementation();
+            if (implementation.matches("^Cyrus.*v([0-1]\\.[0-9].*|2\\.[0-2].*|2\\.3\\.[0-9]|2\\.3\\.[0-9][^0-9].*)$") || implementation.startsWith("NEMESIS")) {
 	            measureStart();
 	            bos_sieve.write(commandBuilder.append("CAPABILITY").append(CRLF).toString().getBytes("UTF-8"));
 	            bos_sieve.flush();
@@ -313,8 +333,8 @@ public class SieveHandler {
             throw new OXSieveHandlerException("Script upload not possible. No Script", sieve_host, sieve_host_port);
         }
 
-        final String put = commandBuilder.append(SIEVE_PUT).append('\"').append(script_name).append("\" {").append(script.length).append(
-            "+}").append(CRLF).toString();
+        final String put =
+            commandBuilder.append(SIEVE_PUT).append('\"').append(script_name).append("\" {").append(script.length).append("+}").append(CRLF).toString();
         commandBuilder.setLength(0);
 
         bos_sieve.write(put.getBytes("UTF-8"));
@@ -608,10 +628,11 @@ public class SieveHandler {
     }
 
     private boolean authPLAIN(final StringBuilder commandBuilder) throws IOException, UnsupportedEncodingException {
-        final String to64 = commandBuilder.append(sieve_user).append('\0').append(sieve_auth).append('\0').append(sieve_auth_passwd).toString();
+        final String to64 =
+            commandBuilder.append(sieve_user).append('\0').append(sieve_auth).append('\0').append(sieve_auth_passwd).toString();
         commandBuilder.setLength(0);
 
-        final String user_auth_pass_64 = commandBuilder.append(convertStringToBase64(to64)).append(CRLF).toString();
+        final String user_auth_pass_64 = commandBuilder.append(convertStringToBase64(to64, sieve_auth_enc)).append(CRLF).toString();
         commandBuilder.setLength(0);
 
         final String auth_mech_string = commandBuilder.append(SIEVE_AUTH).append("\"PLAIN\" ").toString();
@@ -664,7 +685,7 @@ public class SieveHandler {
             }
         }
 
-        final String user64 = commandBuilder.append(convertStringToBase64(sieve_auth)).append(CRLF).toString();
+        final String user64 = commandBuilder.append(convertStringToBase64(sieve_auth, sieve_auth_enc)).append(CRLF).toString();
         commandBuilder.setLength(0);
 
         final String user_size = commandBuilder.append('{').append((user64.length() - 2)).append("+}").append(CRLF).toString();
@@ -686,7 +707,7 @@ public class SieveHandler {
             }
         }
 
-        final String pass64 = commandBuilder.append(convertStringToBase64(sieve_auth_passwd)).append(CRLF).toString();
+        final String pass64 = commandBuilder.append(convertStringToBase64(sieve_auth_passwd, sieve_auth_enc)).append(CRLF).toString();
         commandBuilder.setLength(0);
 
         final String pass_size = commandBuilder.append('{').append((pass64.length() - 2)).append("+}").append(CRLF).toString();
@@ -715,7 +736,8 @@ public class SieveHandler {
             throw new OXSieveHandlerException("Activate a script not possible. Auth first.", sieve_host, sieve_host_port);
         }
 
-        final String active = commandBuilder.append(SIEVE_ACTIVE).append('\"').append(sieve_script_name).append('\"').append(CRLF).toString();
+        final String active =
+            commandBuilder.append(SIEVE_ACTIVE).append('\"').append(sieve_script_name).append('\"').append(CRLF).toString();
         commandBuilder.setLength(0);
 
         bos_sieve.write(active.getBytes("UTF-8"));
@@ -817,12 +839,15 @@ public class SieveHandler {
     }
 
     /**
-     * @param toConvert
-     * @return Base64String
-     * @throws UnsupportedEncodingException
+     * COnverts given string to Base64 using given charset encoding.
+     * 
+     * @param toConvert The string to convert to Base64
+     * @param charset The charset encoding to use when retrieving bytes from passed string
+     * @return The Base64 string
+     * @throws UnsupportedEncodingException If charset encoding is unknown
      */
-    private String convertStringToBase64(final String toConvert) throws UnsupportedEncodingException {
-        final String converted = com.openexchange.tools.encoding.Base64.encode(toConvert.getBytes("UTF-8"));
+    private static String convertStringToBase64(final String toConvert, final String charset) throws UnsupportedEncodingException {
+        final String converted = com.openexchange.tools.encoding.Base64.encode(toConvert.getBytes(charset));
         return converted.replaceAll("(\\r)?\\n", "");
     }
 
